@@ -22,6 +22,7 @@ from .io import FlvReader, FlvWriter
 from .io_protocols import RandomIO
 from .utils import format_offest, format_timestamp
 from .exceptions import (
+    FlvDataError,
     FlvStreamCorruptedError,
     AudioParametersChanged,
     VideoParametersChanged,
@@ -30,7 +31,7 @@ from .exceptions import (
     CutStream,
 )
 from .common import (
-    is_audio_tag, is_metadata_tag, is_video_tag, parse_metadata, rpeek_tags,
+    is_audio_tag, is_metadata_tag, is_video_tag, parse_metadata,
     enrich_metadata, update_metadata, is_data_tag, read_tags_in_duration,
     is_sequence_header
 )
@@ -85,7 +86,6 @@ class StreamProcessor:
         self._delta: int = 0
         self._has_audio: bool = False
         self._metadata_tag: ScriptTag
-        self._last_ts: int = 0
         self._last_tags: List[FlvTag] = []
         self._join_points: List[JoinPoint] = []
 
@@ -199,6 +199,7 @@ class StreamProcessor:
 
     def _reset(self) -> None:
         self._discard_file()
+        self._last_tags = []
         self._stream_count = 0
         logger.debug('Reset stream processing')
 
@@ -211,7 +212,7 @@ class StreamProcessor:
 
         try:
             first_data_tag = self._read_first_data_tag()
-            if self._stream_count == 1:
+            if not self._last_tags:
                 self._process_initial_stream(flv_header, first_data_tag)
             else:
                 self._process_subsequent_stream(first_data_tag)
@@ -235,7 +236,9 @@ class StreamProcessor:
         except Exception:
             self._reset()
             raise
-        del first_data_tag
+        else:
+            del flv_header, first_data_tag
+
         self._transfer_tags_until_complete()
 
     def _process_subsequent_stream(self, first_data_tag: FlvTag) -> None:
@@ -373,6 +376,8 @@ class StreamProcessor:
             except EOFError:
                 logger.debug('The input stream exhausted')
                 break
+            except FlvDataError as e:
+                raise FlvStreamCorruptedError(repr(e))
             except Exception as e:
                 logger.debug(f'Failed to read data, due to: {repr(e)}')
                 raise
@@ -391,9 +396,6 @@ class StreamProcessor:
         finally:
             logger.debug(f'{count} tags have been transfered')
 
-            if count > 0:
-                self._update_last_out_tags()
-
     def _add_join_point(
         self, offset: int, timestamp: int, seamless: bool
     ) -> None:
@@ -401,11 +403,6 @@ class StreamProcessor:
         self._join_points.append(join_point)
         logger.debug(f'{repr(join_point)}; {join_point}')
 
-    def _update_last_out_tags(self) -> None:
-        self._last_tags = list(rpeek_tags(
-            self._out_file, self._out_reader, self._TAG_SEQUENCE_COUNT
-        ))
-
     def _find_last_duplicated_tag(self, tags: List[FlvTag]) -> int:
         logger.debug('Finding duplicated tags...')
 
@@ -464,17 +461,18 @@ class StreamProcessor:
         self._size_updates.on_next(size)
 
     def _write_tag(self, tag: FlvTag) -> None:
-        if self._analyse_data:
-            offset = self._out_file.tell()
-            tag = tag.evolve(offset=offset)
+        offset = self._out_file.tell()
+        tag = tag.evolve(offset=offset)
 
         try:
             size = self._out_writer.write_tag(tag)
         except Exception as exc:
             logger.debug(f'Failed to write data, due to: {repr(exc)}')
             raise
-
-        self._last_ts = tag.timestamp
+        else:
+            self._last_tags.insert(0, tag)
+            if len(self._last_tags) > self._TAG_SEQUENCE_COUNT:
+                self._last_tags.pop()
 
         self._stream_cutter.check_tag(tag)
         if not self._disable_limit:
@@ -518,9 +516,13 @@ class StreamProcessor:
     def _enrich_metadata(
         self, old_metadata_tag: ScriptTag, offset: int
     ) -> ScriptTag:
-        # ensure the duration and filesize property exists in the metadata and
-        # init them.
-        self._metadata.update({'duration': 0.0, 'filesize': 0.0})
+        # ensure nesessary properties exists in the metadata and init them.
+        metadata = parse_metadata(old_metadata_tag)
+        self._metadata.update({
+            'duration': 0.0,
+            'filesize': 0.0,
+            'framerate': metadata.get('framerate', metadata.get('fps', 0.0)),
+        })
         # merge the metadata into the metadata tag
         return enrich_metadata(old_metadata_tag, self._metadata, offset)
 
@@ -552,7 +554,14 @@ class StreamProcessor:
         last_tag = self._last_tags[0]
         duration = last_tag.timestamp / 1000
         filesize = float(last_tag.next_tag_offset)
-        updates = dict(duration=duration, filesize=filesize)
+        updates = {
+            'duration': duration,
+            'filesize': filesize,
+        }
+        if self._analyse_data:
+            updates.update({
+                'framerate': self._data_analyser.calc_frame_rate(),
+            })
         self._metadata_tag = update_metadata(self._metadata_tag, updates)
         self._out_file.seek(self._metadata_tag.offset)
         self._out_writer.write_tag(self._metadata_tag)
