@@ -2,6 +2,7 @@ from .helpers import (
     file_exists,
     create_file,
     danmaku_path,
+    cover_path,
     raw_danmaku_path,
     extra_metadata_path,
     escape_path,
@@ -12,6 +13,7 @@ __all__ = (
     'file_exists',
     'create_file',
     'danmaku_path',
+    'cover_path',
     'raw_danmaku_path',
     'extra_metadata_path',
     'escape_path',
